@@ -1,5 +1,6 @@
 'use strict'
 
+const process = require('process')
 const path = require('path')
 const os = require('os')
 const aws = require(path.join(__dirname, 'aws'))
@@ -215,6 +216,7 @@ Emulate only the body of the API Gateway event.
       Description: program.description,
       MemorySize: program.memorySize,
       Timeout: program.timeout,
+      Architectures: program.architecture ? [program.architecture] : ['x86_64'],
       Publish: (() => {
         if (typeof program.publish === 'boolean') {
           return program.publish
@@ -429,6 +431,11 @@ Emulate only the body of the API Gateway event.
   }
 
   _packageInstall (program, codeDirectory) {
+    if (!fs.existsSync(path.join(codeDirectory, 'package.json'))) {
+      console.log('Skip the installation of the package. (Because package.json is not found.)')
+      return
+    }
+
     // Run on windows:
     // https://nodejs.org/api/child_process.html#child_process_spawning_bat_and_cmd_files_on_windows
 
@@ -605,7 +612,8 @@ Emulate only the body of the API Gateway event.
   async _uploadExisting (lambda, params) {
     const functionCodeParams = Object.assign({
       FunctionName: params.FunctionName,
-      Publish: params.Publish
+      Publish: params.Publish,
+      Architectures: params.Architectures
     }, params.Code)
 
     const functionConfigParams = {
@@ -729,7 +737,9 @@ they may not work as expected in the Lambda environment.
     if (!program.keepNodeModules) {
       console.log('=> Running package install')
       const usedPackageManager = await this._packageInstall(program, codeDirectory)
-      console.log(`(Package manager used was '${usedPackageManager}'.)`)
+      if (usedPackageManager) {
+        console.log(`(Package manager used was '${usedPackageManager}'.)`)
+      }
     }
     await this._postInstallScript(program, codeDirectory)
     console.log('=> Zipping deployment package')
