@@ -1,5 +1,6 @@
 'use strict'
 
+const process = require('process')
 const path = require('path')
 const os = require('os')
 const fs = require('fs-extra')
@@ -133,8 +134,8 @@ const _awsRestore = () => {
 describe('lib/main', function () {
   if (['win32', 'darwin'].includes(process.platform)) {
     // It seems that it takes time for file operation in Windows and Mac.
-    // So set `timeout(60000)` for the whole test.
-    this.timeout(60000)
+    // So set `timeout(120000)` for the whole test.
+    this.timeout(120000)
   }
 
   let aws = null // mock
@@ -150,7 +151,7 @@ describe('lib/main', function () {
   })
 
   it('version should be set', () => {
-    assert.equal(lambda.version, '0.21.0')
+    assert.equal(lambda.version, '0.22.0')
   })
 
   describe('_codeDirectory', () => {
@@ -740,6 +741,9 @@ describe('lib/main', function () {
       const packageJson = require(packageJsonPath)
       packageJson.optionalDependencies = { npm: '*' }
       fs.writeFileSync(packageJsonPath, JSON.stringify(packageJson))
+
+      // Remove package-lock.json because it does not match the package.json to which optionalDependencies was added.
+      fs.removeSync(path.join(codeDirectory, 'package-lock.json'))
     }
 
     const testOptionalDependenciesIsInstalled = async (packageManager) => {
